=================
Quantum Mechanics
=================

.. topic:: Abstract

   Contains Docstrings of Physics-Quantum module

Quantum Functions
=================

.. toctree::
   :titlesonly:

   anticommutator.rst
   cg.rst
   commutator.rst
   constants.rst
   dagger.rst
   innerproduct.rst
   tensorproduct.rst

States and Operators
====================

.. toctree::
   :titlesonly:

   cartesian.rst
   hilbert.rst
   operator.rst
   operatorset.rst
   qapply.rst
   represent.rst
   spin.rst
   state.rst

Quantum Computation
===================

.. toctree::
   :titlesonly:

   circuitplot.rst
   gate.rst
   grover.rst
   qft.rst
   qubit.rst
   shor.rst

Analytic Solutions
==================


.. toctree::
   :titlesonly:

   piab.rst
